@@ -436,20 +436,25 @@ class ResampleBoostClassifier(ImbalancedEnsembleClassifierMixin,
 
             # Early termination.
             if sample_weight is None:
+                print (f"Training early-stop at iteration"
+                       f" {iboost+1}/{self.n_estimators}"
+                       f" (sample_weight is None).")
                 break
             
             # Stop if error is zero.
             if estimator_error == 0:
-                print (
-                    f"Training early-stop at iteration {iboost+1}"
-                    f" (training error is 0)."
-                    )
+                print (f"Training early-stop at iteration"
+                       f" {iboost+1}/{self.n_estimators}"
+                       f" (training error is 0).")
                 break
 
             sample_weight_sum = np.sum(sample_weight)
 
             # Stop if the sum of sample weights has become non-positive.
             if sample_weight_sum <= 0:
+                print (f"Training early-stop at iteration"
+                       f" {iboost+1}/{self.n_estimators}"
+                       f" (sample_weight_sum <= 0).")
                 break
 
             if iboost < self.n_estimators - 1:
@@ -815,20 +820,25 @@ class ReweightBoostClassifier(ImbalancedEnsembleClassifierMixin,
 
             # Early termination.
             if sample_weight is None:
+                print (f"Training early-stop at iteration"
+                       f" {iboost+1}/{self.n_estimators}"
+                       f" (sample_weight is None).")
                 break
             
             # Stop if error is zero.
             if estimator_error == 0:
-                print (
-                    f"Training early-stop at iteration {iboost+1}"
-                    f" (training error is 0)."
-                    )
+                print (f"Training early-stop at iteration"
+                       f" {iboost+1}/{self.n_estimators}"
+                       f" (training error is 0).")
                 break
 
             sample_weight_sum = np.sum(sample_weight)
 
             # Stop if the sum of sample weights has become non-positive.
             if sample_weight_sum <= 0:
+                print (f"Training early-stop at iteration"
+                       f" {iboost+1}/{self.n_estimators}"
+                       f" (sample_weight_sum <= 0).")
                 break
 
             if iboost < self.n_estimators - 1:
