@@ -90,7 +90,7 @@ class CompatibleBaggingClassifier(ImbalancedEnsembleClassifierMixin,
         If None, then the base estimator is a
         :class:`~sklearn.tree.DecisionTreeClassifier`.
 
-    n_estimators : int, default=10
+    n_estimators : int, default=50
         The number of base estimators in the ensemble.
 
     max_samples : int or float, default=1.0
@@ -195,7 +195,7 @@ class CompatibleBaggingClassifier(ImbalancedEnsembleClassifierMixin,
     @_deprecate_positional_args
     def __init__(self,
                 base_estimator=None,
-                n_estimators=10,
+                n_estimators:int=50,
                 *,
                 max_samples=1.0,
                 max_features=1.0,
@@ -237,7 +237,7 @@ class CompatibleBaggingClassifier(ImbalancedEnsembleClassifierMixin,
             max_samples=None,
             eval_datasets:dict=None,
             eval_metrics:dict=None,
-            train_verbose:bool=True,
+            train_verbose:bool or int or dict=False,
             ):
         """Build a Bagging ensemble of estimators from the training set (X, y).
 
